MOJBASE = "https://api.ashcon.app/"
MOJUUID = "https://api.mojang.com/users/profiles/minecraft/"
MOJHIST = "user/profiles/{0}/names"
MOJIGN = "https://sessionserver.mojang.com/session/minecraft/profile/"

VOXYLAPIKEY = ""
VOXYLAPI = "?api={0}"
VOXYLBASE = "https://api.voxyl.net/"
VOXYLINFO = "player/info/{0}{1}"
VOXYLOVERALL = "player/stats/overall/{0}{1}"
VOXYLGAME = "player/stats/game/{0}{1}"
VOXYLGUILDINFO = "guild/info/{0}{1}"
VOXYLGUILDMEMBERS = "guild/members/{0}{1}"
VOXYLGUILDTOP = "guild/top{0}&num={1}"
VOXYLANNOUNCEMENTS = "announcement/all{0}"
VOXYLLB = {"level": "leaderboard/normal{0}&num={1}&type=level", "weighted": "leaderboard/normal{0}&num={1}&type=weightedwins", "weightedwins": "leaderboard/normal{0}&num={1}&type=weightedwins", "technique": "leaderboard/technique{0}&technique={1}"}

DEFAULTINFO = {"success": True, "lastLoginName": "", "lastLoginTime": 0, "role": ""}
DEFAULTOVER = {'success': True, 'level': 0, 'exp': 0, 'weightedwins': 0}
DEFAULTGAME = {'bridgesDouble': {'beds': '', 'finals': '', 'kills': '', 'wins': ''}, 'pearlFightSingle': {'kills': '', 'wins': ''}, 'resourceOldSingle': {'kills': ''}, 'bedwarsMegaSolo': {'beds': '', 'finals': '', 'kills': '', 'wins': ''}, 'rankedFoursPractice': {'beds': '', 'finals': '', 'kills': '', 'wins': ''}, 'bowFightSingle': {'kills': '', 'wins': ''}, 'resourceOldDouble': {'kills': '', 'wins': ''}, 'bedwarsLateSingle': {'beds': '', 'finals': '', 'kills': '', 'wins': ''}, 'voidDouble': {'beds': '', 'finals': '', 'kills': '', 'wins': ''}, 'rankedFours': {'beds': '', 'finals': '', 'kills': '', 'wins': ''}, 'groundDouble': {'finals': '', 'kills': '', 'wins': ''}, 'bedRushSingle': {'kills': '', 'wins': ''}, 'flatFightDouble': {'kills': '', 'wins': ''}, 'compBridgeSingle': {'beds': '', 'finals': '', 'kills': '', 'wins': ''}, 'ladderFightSingle': {'beds': '', 'finals': '', 'kills': '', 'wins': ''}, 'ladderFightDouble': {'beds': '', 'finals': '', 'kills': '', 'wins': ''}, 'voidSingle': {'beds': '', 'finals': '', 'kills': '', 'wins': ''}, 'resourceDouble': {'kills': '', 'wins': ''}, 'obstacleSingle': {'wins': ''}, 'bridgesSingle': {'beds': '', 'finals': '', 'kills': '', 'wins': ''}, 'bowFightDouble': {'kills': '', 'wins': ''}, 'miniwarsDouble': {'finals': '', 'kills': '', 'wins': ''}, 'resourceSingle': {'kills': '', 'wins': ''}, 'pearlFightDouble': {'kills': '', 'wins': ''}, 'bedwarsLateDouble': {'beds': '', 'finals': '', 'kills': '', 'wins': ''}, 'sumo': {'kills': '', 'wins': ''}, 'bedRushDouble': {'kills': '', 'wins': ''}, 'partyGames': {'wins': ''}, 'bedwarsEightSolo': {'finals': '', 'kills': ''}, 'bedwarsNormalSingle': {'beds': '', 'finals': '', 'kills': '', 'wins': ''}, 'bedwarsMegaDouble': {'beds': '', 'finals': '', 'kills': '', 'wins': ''}, 'stickFightSingle': {'kills': '', 'wins': ''}, 'flatFightSingle': {'kills': '', 'wins': ''}, 'miniwarsSolo': {'beds': '', 'finals': '', 'kills': '', 'wins': ''}, 'groundSingle': {'beds': '', 'finals': '', 'kills': '', 'wins': ''}, 'betaSumo': {'kills': '', 'wins': ''}, 'bedwarsNormalDouble': {'beds': '', 'finals': '', 'kills': '', 'wins': ''}, 'stickFightDouble': {'kills': '', 'wins': ''}, 'bedwalls': {'beds': '', 'finals': '', 'kills': ''}}
DEFAULTUUID = "7dc5566d-4c2c-40dd-891c-4717d8f44713"